@@ -14,7 +14,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: aic.c,v 1.18 2002/11/14 18:38:03 beerli Exp $ 
+$Id: aic.c,v 1.19 2003/05/31 15:10:15 beerli Exp $ 
 -------------------------------------------------------*/
 #include "migration.h"
 #include "tools.h"
@@ -180,7 +180,7 @@ void aic_print_driver(aic_fmt *aicvec, double mleaic, long aicnum, nr_fmt *nr, w
     long i;
     char *temppattern;
     boolean mldone=FALSE;
-    char dashes[100] = "----------------------------------------------------------------------------------------------------";
+    char dashes[101] = "----------------------------------------------------------------------------------------------------";
     temppattern = calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
     FPRINTF (world->outfile,
              "%-*.*s  AIC     #param   Log(L)   LRT        Prob    Probc\n",
@@ -545,7 +545,7 @@ legal_pattern (char *matrix, long numpop)
 {
     long from, to, i;
     double summ = -1;
-    double oldto;
+    long oldto;
     for (i = 0; i < numpop; i++)
     {
         if (matrix[i] == '0')
