@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: bayes.c,v 1.14 2002/11/27 16:17:13 beerli Exp $
+ $Id: bayes.c,v 1.15 2003/05/31 15:10:15 beerli Exp $
 */
 
 #include "bayes.h"
@@ -235,7 +235,7 @@ void bayes_stat(world_fmt *world)
   long size;
   long numpop2 = world->numpop2;
   long mode;
-  long weight;
+  //long weight;
 #ifdef LONGSUM
   long addon = (world->fluctuate ? world->numpop * 3 : 0);
 #else
@@ -258,7 +258,8 @@ void bayes_stat(world_fmt *world)
   for(j=1; j< size; j++)
     rawstat[j] = rawstat[0] + j * bayes->numparams;
   mode = 0;
-  // find the mode so that we can (1) have the mode and (2) know the max weight for the
+  // find the mode so that we can (1) have the mode and
+  // obsolete? (2) know the max weight for the
   // weighted average.
   for(i=0; i< bayes->numparams; i++)
     {
@@ -267,7 +268,7 @@ void bayes_stat(world_fmt *world)
   for(i=0; i< bayes->numparams; i++)
     {
       FPRINTF(world->bayesfile, "%f ", bayes->params[i][0]);
-      weight =  exp(bayes->params[i][0] -  bayes->params[mode][0]);
+      //weight =  exp(bayes->params[i][0] -  bayes->params[mode][0]);
       for(j = 0; j < size; j++)
         {
 	  temp = bayes->params[i][j+1];
