@@ -18,7 +18,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: broyden.c,v 1.66 2002/12/22 04:50:39 beerli Exp $
+ $Id: broyden.c,v 1.68 2003/06/10 15:55:19 beerli Exp $
 -------------------------------------------------------*/
 extern double norm (double *d, long size);
 
@@ -55,7 +55,7 @@ double probG2 (double *param, double *lparam, double *sm, double *kt,
                long numpop);
 void probG3 (double *apg, double *apg0r, timearchive_fmt * tyme, long numpop,
              double *apgmax, double *param, double *lparam, double *sm);
-inline double probG4 (double *fullparam, double *data, long numpop, long numpop2);
+ double probG4 (double *fullparam, double *data, long numpop, long numpop2);
 double logprob_noevent (world_fmt * world, long interval);
 double sum_migprob (world_fmt * world, long pop, long interval);
 double sum_mig (double *param, long msta, long msto);
@@ -179,7 +179,7 @@ calc_line_new (helper_fmt * helper, double a, double b, double c,
     double xlow = a;
     double low, high, mid, xmid;
     double xguess;
-    long panic = 0;
+    int panic = 0;
     low = (*fpsi) (xlow, helper);
     high = (*fpsi) (xhigh, helper);
     xmid = (xlow + xhigh) / 2.;
@@ -1623,7 +1623,7 @@ check_symmetric_d (double *grad, nr_fmt * nr, long nn)
     {
         for (i = 0; i < sym2n; i++)
         {
-            sq1 = nr->param[sym2s[i][2]] ;//* nr->param[sym2s[i][2]]);
+            sq1 = nr->param[sym2s[i][2]] ;// * nr->param[sym2s[i][2]]);
             sq2 = nr->param[sym2s[i][3]];// * nr->param[sym2s[i][3]]);
             z = 0;
             while (nr->indeks[z] != sym2s[i][0] && z++ < nr->partsize)
@@ -1649,7 +1649,7 @@ check_symmetric_d (double *grad, nr_fmt * nr, long nn)
         for (i = 0; i < sym2n; i++)
         {
             sq1 = nr->param[sym2s[i][2]];// * nr->param[sym2s[i][2]];
-            sq2 = nr->param[sym2s[i][3]];//* nr->param[sym2s[i][3]];
+            sq2 = nr->param[sym2s[i][3]];// * nr->param[sym2s[i][3]];
             mm = (grad[sym2s[i][0]] / sq1 + grad[sym2s[i][1]] / sq2);
             grad[sym2s[i][0]] = mm * sq1;
             grad[sym2s[i][1]] = mm * sq2;
@@ -1714,7 +1714,7 @@ probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
     return result;
 }
 
-inline double
+ double
 probG4 (double *fullparam, double *data, long numpop, long numpop2)
 {
     int i;
