@@ -23,7 +23,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c,v 1.84 2002/12/22 04:50:40 beerli Exp $
+$Id: combroyden2.c,v 1.87 2003/06/10 15:55:19 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -452,7 +452,7 @@ combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv)
             memcpy (gxv, nr->d, sizeof (double) * nr->partsize);*/
             //#else
             //   dt (gxv, helper);
-            //endif  /*LAGUERRE*/
+            //endif  ****LAGUERRE****
         }
 #endif /*MPI*/
 
@@ -1096,7 +1096,8 @@ do_profiles (world_fmt * world, nr_fmt * nr, double *likes,
         i++;
     }
     nr->profilenum = z;
-    world->locus = world->loci;
+    if(kind!=SINGLELOCUS)
+      world->locus = world->loci;
     trials = maximize (world->param0, world, nr, kind, repkind);
     return trials;
 }
