@@ -17,16 +17,16 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h,v 1.77 2002/12/22 04:50:43 beerli Exp $
+$Id: definitions.h,v 1.81 2003/06/10 15:55:19 beerli Exp $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.1"
+#define MIGRATEVERSION "1.7.3"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.1"
+#define MIGRATEVERSION "1.7.3"
 #endif
 #endif
 
@@ -222,8 +222,10 @@ typedef unsigned char boolean;
    MUST really be bigger than the number of 
    observed alleles, much bigger does not harm */
 #define MAXALLELES            93
+#define SMALLBUFSIZE    255
 #define MAXBUFSIZE        100000
-#define LINESIZE            1024 /* setting this smaller can break */
+/* #define LINESIZE            1024*/ /* setting this smaller can break */
+#define LINESIZE           10000 
 #define LONGLINESIZE       10000 /* setting this smaller can break */
 #define STRSIZE              255 /* setting this smaller can break */
 #define DEFAULT_NMLENGTH      10 /* length of individual names */
@@ -325,7 +327,7 @@ long chains is used */
 #define STD22 1.0 /*0.1*/  /*"standard deviation" for penalizer 2*std*std=2*0.223607^2 */
 #define STD2 1.0 /*0.05*/  /* std*std = 0.223607^2 */
 #define LOGSTD 0.0 /*-1.49786613677699549672*/ /*LOG(std)*/
-//#define INVTWOSQRTPILOGSTD /*0.57892760357232275494*/ /* log(1/(std sqrt[2 pi])) */
+/* #define INVTWOSQRTPILOGSTD currently UNUSED*/ /*0.57892760357232275494*/ /* log(1/(std sqrt[2 pi])) */
 #define INVTWOSQRTPILOGSTD -0.91893853320467274178
 #define NTRIALS             1000
 #define LOCI_NORM          0.00001
