@@ -21,7 +21,7 @@ and of course the documentation at:
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: main.c,v 1.91 2002/12/22 04:50:45 beerli Exp $
+$Id: main.c,v 1.95 2003/06/10 15:55:19 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -300,7 +300,7 @@ main(int argc, char **argv)
     if (options->writelog && myID==MASTER)
         print_menu_title(options->logfile, options);
     EARTH->repkind = SINGLECHAIN;
-    unset_penalizer_function(TRUE); // install penalizer for far jumps in MCMC
+    unset_penalizer_function(FALSE); // install penalizer for far jumps in MCMC
     if (!options->readsum)
     {
         //MCMC sampling
@@ -485,8 +485,11 @@ combine_loci(char type, option_fmt * options, world_fmt * world, long *Gmax)
 #ifdef LONGSUM
             change_longsum_times(world); //multilocus
 #endif /*LONGSUM*/
-            
-            estimateParameter(options->replicatenum, *Gmax, world, options,
+#ifdef MPI
+            // broadcast Gmax to all workers, the worker pendant is in mpi_gmax_worker
+            MYMPIBCAST (Gmax, 1, MPI_LONG, MASTER, comm_world);
+#endif
+            (void) estimateParameter(options->replicatenum, *Gmax, world, options,
                               world->cov[world->loci], 0 /* chain */ ,
                               type, kind, world->repkind);
 #ifdef MPI
@@ -494,11 +497,11 @@ combine_loci(char type, option_fmt * options, world_fmt * world, long *Gmax)
         }
         else
         {
-            //printf("%i> before gmax worker\n", myID);
+//            printf("%i> before gmax worker\n", myID);
             mpi_gmax_worker(world);
             mpi_startparam_worker(world);
-            //printf("%i> start worker postlike calculations\n", myID);
-            mpi_maximize_worker(world, options->replicatenum);
+//            printf("%i> start worker postlike calculations\n", myID);
+            mpi_maximize_worker(world, options->replicatenum); // receive broadcast for Gmax
         }
 #endif
     }
@@ -741,7 +744,8 @@ print_progress(worldoption_fmt * options, world_fmt * world, long rep,
         if (!world->start && world->chains > 1 && options->verbose)
             print_gelmanr(world->gelmanmeanR, world->gelmanmaxR);
     }
-    world->accept_freq = world->accept = 0;
+    world->accept_freq = 0. ;
+    world->accept = 0L ;
 }
 
 void
@@ -813,10 +817,10 @@ print_heating_progress(world_fmt ** universe, worldoption_fmt * options,
       universe[1]->swapped = 0;
       universe[0]->swapped = 0;
 
-      universe[0]->accept = 0.;
-      universe[1]->accept = 0.;
-      universe[2]->accept = 0.;
-      universe[3]->accept = 0.;
+      universe[0]->accept = 0L;
+      universe[1]->accept = 0L;
+      universe[2]->accept = 0L;
+      universe[3]->accept = 0L;
 
       universe[0]->accept_freq = 0.;
       universe[1]->accept_freq = 0.;
@@ -872,7 +876,7 @@ analyze_olddata(world_fmt * world,
         for (pop = 0; pop < world->numpop; pop++)
         {
             data->popnames[pop] = (char *) calloc (1, sizeof (char) * LINESIZE);
-            sprintf(data->popnames[pop],"Pop_%li ",pop+1); 
+            snprintf(data->popnames[pop], LINESIZE, "Pop_%li ",pop+1); 
         }
         
 #ifdef MPI
@@ -934,7 +938,7 @@ analyze_olddata(world_fmt * world,
 #ifdef LONGSUM
                 change_longsum_times(world);//multi run replicates
 #endif /*LONGSUM*/                
-                estimateParameter(options->replicatenum, Gmax, world, options,
+                (void) estimateParameter(options->replicatenum, Gmax, world, options,
                                   world->cov[locus], 1, 'l',
                                   SINGLELOCUS, world->repkind);
             }
@@ -999,7 +1003,7 @@ profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
 
         for (i = 0; i < len; i++)
         {
-            print_profile_likelihood_driver(i, world, gmaxptr);
+            (void) print_profile_likelihood_driver(i, world, gmaxptr);
             FPRINTF(world->outfile, "%s\n\n", world->buffer);
             world->buffer[0] = '\0';
         }
@@ -1007,6 +1011,7 @@ profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
         if (myID == MASTER && options->printprofsummary)
         {
             print_profile_percentile(world);
+            // print profile summary
             FPRINTF(world->outfile, "%s\n\n", world->buffer);
             world->buffer[0] = '\0';
             destroy_profile_percentiles(world);
@@ -1119,7 +1124,7 @@ condense_time(world_fmt * world, long *step, long *j, double *accepted,
     }
     if (*step >= oldsteps - 1 && world->options->movingsteps)
     {
-        if (*G + 1 < world->options->acceptfreq * oldsteps)
+        if (((double)(*G + 1)) < world->options->acceptfreq * oldsteps)
         {
             (*steps)++;
         }
@@ -1148,7 +1153,7 @@ heating_init(world_fmt ** universe, int usize, data_fmt * data,
     char            tmp[20];
     for (chain = 1; chain < usize; ++chain)
     {
-        sprintf(tmp, "%10.5f", options->heat[chain]);
+        snprintf(tmp, 20, "%10.5f", options->heat[chain]);
         strncpy(this_string, tmp, 10);
         create_world(&universe[chain], this_string, data->loci);
         init_world(universe[chain], data, options);
@@ -1194,7 +1199,7 @@ heating_prepare2(world_fmt ** universe, int usize)
             universe[chain]->bayesaccept = bayes_update(universe[chain]);
 #endif
 
-        tree_update(universe[chain], 0);
+        (void) tree_update(universe[chain], 0);
     }
 }
 
@@ -1239,7 +1244,7 @@ run_locus(world_fmt ** universe, int usize, option_fmt * options,
         change_longsum_times(EARTH);
 #endif /*LONGSUM*/        
         // over multiple replicates if present or single locus
-        estimateParameter(options->replicatenum, *Gmax, EARTH, options,
+        (void) estimateParameter(options->replicatenum, *Gmax, EARTH, options,
                           EARTH->cov[locus], options->lchains, /*type*/ 'l',
                           SINGLELOCUS, EARTH->repkind);
     }
@@ -1341,7 +1346,7 @@ run_steps(world_fmt **universe,
           {
             advance_clone_like(EARTH, EARTH->accept,
                             &EARTH->G);
-            EARTH->accept = 0;
+            EARTH->accept = 0L;
           }
         // if we do heating
         if(EARTH->options->heating)
@@ -1353,13 +1358,12 @@ run_steps(world_fmt **universe,
                 advance_clone_like(universe[ii],
                                 universe[ii]->accept,
                                 &(universe[ii])->G);
-                universe[ii]->accept = 0;
+                universe[ii]->accept = 0L;
               }
           }
     }
 }
 
-
 void run_chains(world_fmt **universe,
                 long usize,
                 option_fmt *options,
@@ -1418,14 +1422,14 @@ void run_chains(world_fmt **universe,
 #ifdef LONGSUM
         change_longsum_times(EARTH);
 #endif /*LONGSUM*/
-        estimateParameter(rep, *Gmax, EARTH, options,
+        (void) estimateParameter(rep, *Gmax, EARTH, options,
                         EARTH->cov[locus], chain, type, kind,
                         EARTH->repkind);
         if(EARTH->options->heating)
             print_heating_progress(universe, EARTH->options, increment * steps);
         else
             print_progress(EARTH->options,EARTH,rep, 
-                           increment * steps, EARTH->accept_freq);
+                           increment * steps, (long) EARTH->accept_freq);
         // cleanup and prepare next
         prepare_next_chain(universe, EARTH->options, type, chain,
                            &chains, &pluschain, locus, replicate);
@@ -1445,7 +1449,7 @@ void set_penalizer(long chain, long chains, char type, world_fmt **universe)
     else
     {
         EARTH->in_last_chain = FALSE;
-        unset_penalizer_function(TRUE);
+        unset_penalizer_function(FALSE);
     }
 }
 
@@ -1507,7 +1511,7 @@ void run_replicate(long locus,
 #ifdef LONGSUM
                 change_longsum_times(EARTH);
 #endif /*LONGSUM*/
-                estimateParameter(replicate, *Gmax, EARTH, options,
+                (void) estimateParameter(replicate, *Gmax, EARTH, options,
                                   EARTH->cov[locus], chains, type,
                                   SINGLELOCUS, EARTH->repkind);
               }
