@@ -17,7 +17,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc2.c,v 1.20 2002/06/20 06:25:36 beerli Exp $
+$Id: mcmc2.c,v 1.21 2002/08/12 21:13:54 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -28,7 +28,7 @@ $Id: mcmc2.c,v 1.20 2002/06/20 06:25:36 beerli Exp $
 #include <dmalloc.h>
 #endif
 
-#define comment(a) fprintf(stderr,a)
+#define comment(a) FPRINTF(stderr,a)
 
 
 /* prototypes ------------------------------------------- */
@@ -680,7 +680,7 @@ t_s_obbncon (proposal_fmt * proposal, node * obb)
 {
 
     node *nn, *oldnn, *d1, *d2;
-    /*     fprintf(stdout,"t_s_obbncon\n"); */
+    /*     FPRINTF(stdout,"t_s_obbncon\n"); */
     pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
                   proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
     nn = showtop (crawlback (obb));
