@@ -10,9 +10,10 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: migrate_mpi.c,v 1.25 2002/11/14 18:38:04 beerli Exp $
+$Id: migrate_mpi.c,v 1.30 2003/06/10 23:21:56 beerli Exp $
 */
 #ifdef MPI
+#include "definitions.h"
 #include "sighandler.h"
 #include "migrate_mpi.h"
 #include "broyden.h"
@@ -70,8 +71,10 @@ mpi_runloci_master (long loci, int *who, world_fmt *world)
     MPI_Status status;
     long numsent = 0;
     boolean done = FALSE;
-    char *rawmessage;
-    rawmessage = (char *) calloc(MAXBUFSIZE,sizeof(char));
+    char *tempstr;
+    long tempstrsize=MAXBUFSIZE;
+
+    tempstr = (char *) calloc(MAXBUFSIZE,sizeof(char));
 
     for (locus = 0; locus < MIN (loci, numcpu - 1); locus++)
     {
@@ -83,19 +86,20 @@ mpi_runloci_master (long loci, int *who, world_fmt *world)
         done=FALSE;
         while(!done)
         {
-            MYMPIRECV (rawmessage, MAXBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE,MPI_ANY_TAG, comm_world, &status);
+            MYMPIRECV (tempstr, SMALLBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE,MPI_ANY_TAG, comm_world, &status);
             sender = status.MPI_SOURCE;
 //            fprintf(stdout,"%i> @@@@%s@@@@\n",sender, rawmessage);
-            switch(rawmessage[0])
+            switch(tempstr[0])
             {
             case 'M':
-                sender = status.MPI_SOURCE;
-                handle_message(rawmessage,sender, world);
+                tempstrsize = atol(tempstr+1);
+                MYMPIRECV (tempstr, tempstrsize, MPI_CHAR, sender, MPI_ANY_TAG,
+                           comm_world, &status);
+                handle_message(tempstr,sender, world);
                 break;
             case 'R':
-                //ignore first characeter and translate into locusnumber
-                locusdone = atol(rawmessage+1);
-                sender = status.MPI_SOURCE;
+                //ignore first character and translate into locusnumber
+                locusdone = atol(tempstr+1);
                 done=TRUE;
                 break;
             default:
@@ -168,14 +172,15 @@ mpi_runreplicates_master (long loci, int *who, world_fmt *world)
     MPI_Status status;
     long numsent = 0;
     boolean done = FALSE;
-    char *rawmessage;
+    char *tempstr;
+    long tempstrsize=MAXBUFSIZE;
     long temp[2];
     long  maxreplicate = (world->options->replicate
                           && world->options->replicatenum >
                           0) ? world->options->replicatenum : 1;
     long locirep = loci * maxreplicate;
     
-    rawmessage = (char *) calloc(MAXBUFSIZE,sizeof(char));
+    tempstr = (char *) calloc(MAXBUFSIZE,sizeof(char));
     // loop over loci and replicates, first loop is only over numcpu 
     for (locrep = 0; locrep < MIN (locirep, numcpu - 1); locrep++)
       {
@@ -190,18 +195,20 @@ mpi_runreplicates_master (long loci, int *who, world_fmt *world)
         done=FALSE;
         while(!done)
           {
-            MYMPIRECV (rawmessage, MAXBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE, MPI_ANY_TAG,
+            MYMPIRECV (tempstr, SMALLBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE, MPI_ANY_TAG,
                       comm_world, &status);
             sender = status.MPI_SOURCE;
             switch(rawmessage[0])
               {
                 case 'M':
-                    sender = status.MPI_SOURCE;
-                    handle_message(rawmessage,sender, world);
+                    tempstrsize = atol(tempstr+1);
+                    MYMPIRECV (tempstr, tempstrsize, MPI_CHAR, sender, MPI_ANY_TAG,
+                               comm_world, &status);
+                    handle_message(tempstr,sender, world);
                     break;
                 case 'R':
                     //ignore first character and translate into locusnumber
-                    sscanf(rawmessage,"R%li:%li",&locusdone,$replicatedone);
+                    sscanf(tempstr,"R%li:%li",&locusdone,$replicatedone);
                     sender = status.MPI_SOURCE;
                     done=TRUE;
                     break;
@@ -385,16 +392,16 @@ mpi_startparam_master(world_fmt * world)
     long i;
     int numreceived = 0;
     long workerloci=0;
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     tmp = (double*) calloc(world->numpop2+1,sizeof(double));
     while (numreceived < world->loci)
       {
-//        printf("wait for data \n");
+       // printf("wait for data \n");
         MYMPIRECV (tmp, world->numpop2+1, MPI_DOUBLE, MPI_ANY_SOURCE,
                    MPI_ANY_TAG, comm_world, &status);
         sender = status.MPI_SOURCE;
         tag = status.MPI_TAG;
- //       printf("received data form node %i with tag %i\n",sender,tag);
+        //printf("received data form node %li with tag %i\n",sender,tag);
         workerloci=tmp[0];
         for(i=0; i<world->numpop2; i++)
             world->param0[i] += tmp[i+1];
@@ -402,7 +409,7 @@ mpi_startparam_master(world_fmt * world)
       }
     for(i=0; i<world->numpop2; i++)
         world->param0[i] /= world->loci;
- // 
+ 
     free(tmp);
 }
 
@@ -416,7 +423,7 @@ mpi_startparam_worker (world_fmt * world)
     long i;
     long locus;
     double *tmp;
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     if(locidone>0)
       {
 //        fprintf("send startparam from node %i\n",myID);
@@ -461,7 +468,8 @@ mpi_gmax_master (world_fmt * world, long *Gmax)
             *Gmax = tmp;
         numreceived++;
     }
-    MYMPIBCAST (Gmax, 1, MPI_LONG, MASTER, comm_world);
+    //  do we need this barrier really?
+    MYMPIBARRIER(comm_world);
 }
 
 void
@@ -487,7 +495,9 @@ mpi_gmax_worker (world_fmt * world)
         }
     }
     MYMPISEND (&Gmax, 1, MPI_LONG, MASTER, myID, comm_world);
-}
+//  do we need this barrier really?
+    MYMPIBARRIER(comm_world);
+  }
 
 
 void
@@ -671,7 +681,7 @@ broadcast_options_master (option_fmt * options)
     char *buffer;
     buffer = (char *) calloc (1, sizeof (char));
     bufsize = save_options_buffer (&buffer, options);
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     MYMPIBCAST (&bufsize, 1, MPI_LONG, MASTER, comm_world);
     MYMPIBCAST (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
     free (buffer);
@@ -683,7 +693,7 @@ broadcast_options_worker (option_fmt * options)
 {
     long bufsize;
     char *buffer, *sbuffer;
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     MYMPIBCAST (&bufsize, 1, MPI_LONG, MASTER, comm_world);
     buffer = (char *) calloc (bufsize + 1, sizeof (char));
     sbuffer = buffer;
@@ -700,7 +710,7 @@ broadcast_data_master (data_fmt * data, option_fmt * options)
     char *buffer;
     buffer = (char *) calloc (1, sizeof (char));
     bufsize = pack_databuffer (&buffer, data, options);
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     MYMPIBCAST (&bufsize, 1, MPI_LONG, MASTER, comm_world);
     MYMPIBCAST (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
     free (buffer);
@@ -711,7 +721,7 @@ broadcast_data_worker (data_fmt * data, option_fmt * options)
 {
     long bufsize;
     char *buffer;
-    MYMPIBARRIER(comm_world);
+    // MYMPIBARRIER(comm_world);
     MYMPIBCAST (&bufsize, 1, MPI_LONG, MASTER, comm_world);
     buffer = (char *) calloc (bufsize, sizeof (char));
     MYMPIBCAST (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
@@ -1498,7 +1508,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
         }
         workload[2*loci]=allbufsize;
         workload[2*loci+1]=(long)loci;
-        MYMPIBARRIER(comm_world);
+        // MYMPIBARRIER(comm_world);
         MYMPIBCAST (workload, 2 * (loci) + 2, MPI_LONG, MASTER, comm_world);
         MYMPIBCAST (allbuffer, allbufsize+1, MPI_CHAR, MASTER, comm_world);
         //printf("%i> Locus %li results sent\n",myID, locus);
@@ -1506,7 +1516,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
     else
     { // worker node
 
-        MYMPIBARRIER(comm_world);
+        // MYMPIBARRIER(comm_world);
         MYMPIBCAST (workload, 2*(loci)+2, MPI_LONG, MASTER, comm_world);
         bufsize =  workload[2*loci] ;
         workerloci = workload[2*loci+1];
@@ -1566,10 +1576,12 @@ mpi_profiles_master (world_fmt * world, long nparam, int *profilewho)
     long bufsize;
     long quantsize;
     char *tempstr;
+    long tempstrsize=MAXBUFSIZE;
+    long temp[3];
     char **buffer = &world->buffer;
     FILE *outfile = world->outfile;
 
-    tempstr = calloc(MAXBUFSIZE,sizeof(char));
+    tempstr = (char*) calloc(MAXBUFSIZE,sizeof(char));
 
     for (pnum = 0; pnum < MIN (nparam, numcpu - 1); pnum++)
     {
@@ -1581,18 +1593,22 @@ mpi_profiles_master (world_fmt * world, long nparam, int *profilewho)
         done = FALSE;
         while(!done)
         {
-            MYMPIRECV (tempstr, MAXBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE, MPI_ANY_TAG, comm_world, &status);
+            MYMPIRECV (tempstr, SMALLBUFSIZE, MPI_CHAR, MPI_ANY_SOURCE, MPI_ANY_TAG, comm_world, &status);
+            sender = status.MPI_SOURCE;
             switch(tempstr[0])
             {
             case 'M':
-                sender = status.MPI_SOURCE;
+                 tempstrsize = atol(tempstr+1);
+                MYMPIRECV (tempstr, tempstrsize, MPI_CHAR, sender, MPI_ANY_TAG,
+                           comm_world, &status);                
                 handle_message(tempstr,sender, world);
                 break;
-            case 'P': sscanf(tempstr+1,"%li%li%li",&pdone,&bufsize,&quantsize);
-                //        pdone = temp[0];
-                //       bufsize = temp[1];
-                //      quantsize = temp[2];
-                sender = status.MPI_SOURCE;
+            case 'P':
+                MYMPIRECV (temp, 3, MPI_LONG, sender, MPI_ANY_TAG,
+                           comm_world, &status);
+                pdone = temp[0];
+                bufsize = temp[1];
+                quantsize = temp[2];
                 profilewho[pdone] = sender;
                 *buffer =
                     (char *) realloc (*buffer, sizeof (char) * (bufsize + quantsize + 1));
@@ -1663,8 +1679,10 @@ mpi_profiles_worker (world_fmt * world, long *gmaxptr)
             }
             else
                 temp[2] = 0;
-            tempstrsize = 1 + sprintf(tempstr,"P%li %li %li", temp[0],temp[1],temp[2]);
-            MYMPISEND (tempstr,tempstrsize, MPI_CHAR, MASTER, pnum + 1, comm_world);
+            tempstrsize = 1 + sprintf(tempstr,"P%li", temp[1]);
+            tempstr[0]='P';
+            MYMPISEND (tempstr, SMALLBUFSIZE , MPI_CHAR, MASTER, pnum + 1, comm_world);
+            MYMPISEND (temp, 3 , MPI_LONG, MASTER, pnum + 1, comm_world);
             MYMPISEND (world->buffer, temp[1] + temp[2], MPI_CHAR, MASTER,
                       pnum + 1, comm_world);
             world->profilewho[profiledone++] = pnum;
@@ -2014,6 +2032,7 @@ void set_filehandle(char *message, world_fmt *world,
 void
 mpi_fprintf(FILE *file, const char *fmt, ...)
 {
+    char p1[SMALLBUFSIZE];
     char *p;
     va_list ap;
     long filehandle = 0;
@@ -2029,6 +2048,8 @@ mpi_fprintf(FILE *file, const char *fmt, ...)
     if(myID!=MASTER)
     {
         bufsize= 1+strlen(p);
+        sprintf(p1,"M%li",bufsize);
+        MYMPISEND (p1, SMALLBUFSIZE, MPI_CHAR, MASTER, myID, comm_world);
         MYMPISEND (p, bufsize, MPI_CHAR, MASTER, myID, comm_world);
     }
     else
