@@ -88,8 +88,11 @@ extern void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 
 extern void mpi_maximize_worker (world_fmt * world, long rep);
 
-extern void mpi_gmax_master (world_fmt * world, long *Gmax);
-extern void mpi_gmax_worker (world_fmt * world);
+extern void mpi_startparam_master(world_fmt * world);
+extern void mpi_startparam_worker(world_fmt * world);
+
+extern void mpi_gmax_master(world_fmt * world, long *Gmax);
+extern void mpi_gmax_worker(world_fmt * world);
 
 extern void mpi_send_stop (world_fmt * world);
 extern void mpi_results_stop (void);
