@@ -208,6 +208,7 @@ typedef struct _option
     double acceptfreq;
     boolean printdata;
     boolean usertree;
+    boolean usertreewithmig;
     boolean randomtree;
     short treeprint;
     boolean usem;
@@ -812,9 +813,7 @@ typedef struct _nr_fmt
     world_fmt *world;
     double **dd;   /* second derivatives */
     double *param;  /* changed values of param */
-    //double *oparam;             /* saved old values of param */
     double *lparam;  /* changed values of log(param) */
-    //  double *olparam;          /* saved old log(parameters) */
     double llike;   /* parameter LOGlikelihood */
     double lastllike;  /* parameter LOGlikelihood */
     double ollike;  /* old "   " */
