@@ -15,7 +15,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c,v 1.63 2002/11/09 20:06:13 beerli Exp $
+$Id: profile.c,v 1.66 2003/07/07 21:14:13 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -701,11 +701,12 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
 #ifndef NOTIME_FUNC
     static long sumtime = 0;
     static long tally = 0;
-    static char nowstr[LINESIZE];
+    char * nowstr;
     time_t endtime;
     time_t nowbin;
     struct tm *nowstruct;
-
+    nowstr = (char *) calloc(LINESIZE,sizeof(char));
+    
     if (tally % nn == 0)
     {
         tally++;
@@ -727,6 +728,7 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
     else
         tally++;
 #endif
+    free(nowstr);
 }
 
 
@@ -1559,11 +1561,14 @@ destroy_profile_percentiles (world_fmt * world)
 void
 print_menu_profile (long which, long nn)
 {
-    char nowstr[LINESIZE];
+    char * nowstr;
+    nowstr = (char*) calloc(LINESIZE,sizeof(char));
+    
     get_time (nowstr, "%H:%M:%S");
     FPRINTF (stdout,
              "%s   Calculating profile likelihoods for parameter %2li out of %2li\n",
              nowstr, 1 + which, nn);
+    free(nowstr);
 }
 
 
