@@ -21,7 +21,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c,v 1.33 2002/12/22 04:50:45 beerli Exp $
+$Id: random.c,v 1.35 2003/06/10 15:55:20 beerli Exp $
 -------------------------------------------------------*/
 
 #include "sighandler.h"
@@ -164,8 +164,8 @@ getseed (option_fmt * options)
     init_sprng (options->inseed, SPRNG_DEFAULT);
 #else /* if we do not have SPRNG */
 
-    //    for (i = 1; i <= 1000; i++) /* clear the random number generator */
-    //        RANDUM ();
+        for (i = 1; i <= 1000; i++) /* clear the random number generator */
+            RANDUM ();
 #ifndef MERSENNE_TWISTER
     for (i = 0; i <= 2; i++)
         seed[i] = 0;
