@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c,v 1.18 2002/08/12 21:13:56 beerli Exp $                  
+   $Id: sighandler.c,v 1.19 2003/05/31 15:10:15 beerli Exp $                  
    ----------------------------------------------------- */
 //#include <stdio.h>
 #ifndef __MWERKS__
@@ -351,7 +351,7 @@ malloc_error_found (int value)
 #undef free
 
 void *
-LAMARC_malloc (const unsigned long size, const char file[], const long line)
+LAMARC_malloc (size_t size, const char file[], const long line)
 {
     void *x;
     x = malloc (size);
@@ -367,7 +367,7 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
 
 
 void *
-LAMARC_calloc (const unsigned long repeats, const unsigned long size,
+LAMARC_calloc (size_t repeats, size_t size,
                const char file[], const long line)
 {
     void *x;
@@ -383,7 +383,7 @@ LAMARC_calloc (const unsigned long repeats, const unsigned long size,
 }
 
 void *
-LAMARC_realloc (void *ptr, const unsigned long size, const char file[],
+LAMARC_realloc (void *ptr, size_t size, const char file[],
                 const long line)
 {
     void *x;
