@@ -38,16 +38,16 @@ extern char *myfgets (char *buffer, long bufsize, FILE * infile);
 extern void malloc_error_found (int value);
 #endif
 #ifdef LAMARC_MALLOC
-extern void *LAMARC_malloc (const unsigned long size, const char file[],
+extern void *LAMARC_malloc (size_t size, const char file[],
                                 const long line);
-extern void *LAMARC_calloc (const unsigned long repeats,
-                                const unsigned long size, const char file[],
+extern void *LAMARC_calloc (size_t repeats,
+                                size_t size, const char file[],
                                 const long line);
-extern void *LAMARC_realloc (void *ptr, const unsigned long size,
+extern void *LAMARC_realloc (void *ptr, size_t,
                                  const char file[], const long line);
-#define malloc(a) LAMARC_malloc((unsigned long) a,__FILE__,__LINE__)
-#define calloc(b,a) LAMARC_calloc((unsigned long) b, a,__FILE__,__LINE__)
-#define realloc(c,a) LAMARC_realloc(c, (unsigned long) a,__FILE__,__LINE__)
+#define malloc(a) LAMARC_malloc((size_t) a,__FILE__,__LINE__)
+#define calloc(b,a) LAMARC_calloc((size_t) b, (size_t) a,__FILE__,__LINE__)
+#define realloc(c,a) LAMARC_realloc(c, (size_t) a,__FILE__,__LINE__)
 #endif
 #ifdef MPI
 #ifdef DEBUG_MPI
